#include "mcell.h"
#include <QDebug>

MCell::MCell(QObject *parent) : QObject(parent), QGraphicsItem()
{
    setAcceptHoverEvents(true);
    focus = false;
    m_state = eClosed;
    m_cellColor = QColor("#7095D4");
    m_cellSize = 20;
}

QRectF MCell::boundingRect() const
{
    return QRectF(0, 0, m_cellSize, m_cellSize);
}

void MCell::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
{
    rectCell.setRect(0, 0, m_cellSize, m_cellSize);

    //focus on cell
    if(focus)
    {
        painter->setBrush(m_cellColor);     // Устанавливаем кисть, которой будем отрисовывать объект
        Q_UNUSED(option);
        Q_UNUSED(widget);
    }
    else
    {
        painter->setBrush(m_cellColor);     // Устанавливаем кисть, которой будем отрисовывать объект
        Q_UNUSED(option);
        Q_UNUSED(widget);
    }
    //draw on click
    if (m_state == eQuestion)
    {
        painter->setPen(Qt::black);
        painter->drawText(rectCell, Qt::AlignCenter, "11");
    }

    painter->drawRect(rectCell);
}

void MCell::mousePressEvent(QGraphicsSceneMouseEvent *event)
{
    if (event->button() == Qt::LeftButton)
    {
        qDebug() << event->pos();
    }
    if (event->button() == Qt::RightButton)
    {
        if (m_state == eClosed)
        {
            m_state = eFlag;
        }
        if (m_state == eFlag)
        {
            m_state = eQuestion;
        }
        if (m_state == eQuestion)
        {
            m_state = eClosed;
        }
    }
    qDebug() << m_state;
}

void MCell::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
{
    if(event && m_state == eClosed)
    {
        focus = true;
        m_cellColor = QColor("#B3CAF2");
    }
    update();
}

void MCell::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
{
    if(event && m_state == eClosed)
    {
        focus = false;
        m_cellColor = QColor("#7095D4");
    }
    update();
}

uint MCell::getAreaXSize()
{
    return m_areaXSize;
}

uint MCell::getAreaYSize()
{
    return m_areaYSize;
}

uint MCell::getCellSize()
{
    return m_cellSize;
}

void MCell::setCellSize(uint size)
{
    m_cellSize = size;
    update();
}

MCell::~MCell()
{
}
